@@ -23,6 +23,7 @@
  * ~~~~~~~ *
  ***********/
 
+#include <sys/stat.h>		// mkdir () function
 #include "../include/game.h"
 
 
@@ -40,23 +41,25 @@
 Game::Game () :
 /* All these widgets are defined in the basic.glade file, and imported with Gtk::Builder */
 // Windows of the game :
-make7window (), make7scores (), make7message (), make7error_board (), make7credits (),
+make7window (), make7scores (), make7message (), make7error_board (),
+make7confirm (), make7askname (), make7credits (),
+// Main window title bar and menu items :
+headerbar (), appmenu (), newgame (), scores (), credits (), quit (),
 // Buttons for the interface :
-button_cancel (), button_close_scores (), button_credits (), button_help (),
-button_new (), button_next (), button_quit (), button_rotate (), button_scores (),
-button_erase (),
+button_cancel (), button_credits (), button_help (),
+button_new (), button_next (), button_quit (), button_rotate (),
+button_save (), button_scores (), button_erase (),
 // Buttons forming the Board :
 nnw (), nn (), nne (), nww (), nw (), ne (), nee (), ww (), w (), m (), e (), ee (), sww (),
 sw (), se (), see (), ssw (), ss (), sse (),
 // Buttons (not clickable) forming the SelectionArea (under the Board) :
 mainNw (), mainNe (), mainW (), mainM (), mainE (), mainSw (), mainSe (),
 // Other miscellaneous widgets :
-current_score (),
-box_score (),
+current_score (), box_score (), user_entry (),
 /* Now these are global (privates) variables, shared between all functions */
 Board (), SelectionArea (), BoardSnapshotMap (), Colors (), BoardKeys (), SelectionAreaKeys (), ColorsKeys (),
 pos2 (), max (), valHexa1 (), valHexa2 (), score (), nMatch (), oldValHexa1 (), oldValHexa2 (),
-CssProvider (), transition (false)
+CssProvider ()
 {
 	// Define keys
 	BoardKeys = { 13, 14, 15, 22, 23, 24, 25,
@@ -88,95 +91,110 @@ Game::connect_every_button ()
 	if (button_close_scores)
 		button_close_scores->signal_clicked ().connect
 		(sigc::mem_fun (*this, &Game::on_close_scores_activate));
-	// Display credits
-	if (button_credits)
-		button_credits->signal_clicked ().connect
-		(sigc::mem_fun (*this, &Game::on_display_credits_activate));
-	// Erase hexa
-	if (button_erase)
-		button_erase->signal_clicked ().connect
-		(sigc::mem_fun (*this, &Game::on_erase_hexa_activate));
 	// Display help
 	if (button_help)
 		button_help->signal_clicked ().connect
 		(sigc::mem_fun (*this, &Game::on_display_help_activate));
-	// New game
-	if (button_new)
-		button_new->signal_clicked ().connect
-		(sigc::mem_fun (*this, &Game::on_new_game_activate));
 	// Next hexa
 	if (button_next)
 		button_next->signal_clicked ().connect
 		(sigc::mem_fun (*this, &Game::on_next_hexa_activate));
-	// Quit game
-	if (button_quit)
-		button_quit->signal_clicked ().connect
-		(sigc::mem_fun (*this, &Game::on_quit_game_activate));
-	// Rotate hexas
-	if (button_rotate)
-		button_rotate->signal_clicked ().connect
-		(sigc::mem_fun (*this, &Game::on_rotate_hexas_activate));
-	// Display scores
-	if (button_scores)
-		button_scores->signal_clicked ().connect
+	/* Menu items */
+	if (newgame)
+		newgame->signal_activate ().connect
+		(sigc::mem_fun (*this, &Game::on_new_game_activate));
+	if (scores)
+		scores->signal_activate ().connect
 		(sigc::mem_fun (*this, &Game::on_display_scores_activate));
-
+	if (credits)
+		credits->signal_activate ().connect
+		(sigc::mem_fun (*this, &Game::on_display_credits_activate));
+	if (quit)
+		quit->signal_activate ().connect
+		(sigc::mem_fun (*this, &Game::on_quit_game_activate));
+	/* Score save entry */
+	if (user_entry)
+		user_entry->signal_editing_done().connect
+		(sigc::mem_fun (*this, &Game::on_entry_editing_done));
 	/* Game buttons */
 	for (int key : BoardKeys)
 		Board [key]->signal_clicked ().connect
 		(sigc::bind<int> (sigc::mem_fun (*this, &Game::game_button_selected), key) );
-	SelectionArea[0]->signal_clicked ().connect
-			(sigc::bind<int> (sigc::mem_fun (*this, &Game::game_button_selected), 0) );
+	SelectionArea[0]->signal_clicked () .connect
+			(sigc::mem_fun (*this, &Game::rotate_hexas_left));
+	SelectionArea[0]->signal_button_press_event () .connect
+			(sigc::mem_fun (*this, &Game::rotate_hexas_right));
 }
 
 void
 Game::display (Glib::RefPtr<Gtk::Application> app)
 {
+	/** Accelerators settings **/
+	newgame->add_accelerator ("activate", make7window->get_accel_group (), 'n',
+			Gdk::CONTROL_MASK, Gtk::ACCEL_VISIBLE);
+	scores->add_accelerator ("activate", make7window->get_accel_group (), 's',
+			Gdk::CONTROL_MASK, Gtk::ACCEL_VISIBLE);
+	credits->add_accelerator ("activate", make7window->get_accel_group (), 'c',
+			Gdk::CONTROL_MASK, Gtk::ACCEL_VISIBLE);
+	quit->add_accelerator ("activate", make7window->get_accel_group (), 'q',
+			Gdk::CONTROL_MASK, Gtk::ACCEL_VISIBLE);
+	button_help->add_accelerator ("activate", make7window->get_accel_group (), 'h',
+			Gdk::CONTROL_MASK, Gtk::ACCEL_VISIBLE);
+	button_erase->add_accelerator ("activate", make7window->get_accel_group (), 'e',
+			Gdk::CONTROL_MASK, Gtk::ACCEL_VISIBLE);
+	button_cancel->add_accelerator ("activate", make7window->get_accel_group (), 'z',
+			Gdk::CONTROL_MASK, Gtk::ACCEL_VISIBLE);
+	button_next->add_accelerator ("activate", make7window->get_accel_group (), ' ',
+			Gdk::CONTROL_MASK, Gtk::ACCEL_VISIBLE);
+
+	/** Window settings **/
 	Glib::RefPtr<Gdk::Pixbuf> icon =
 			Gdk::Pixbuf::create_from_file (ICON_DIR "/32x32/apps/make7libre.png");
 	make7window->set_icon (icon);
+	make7window->set_has_resize_grip (true);
 	Glib::RefPtr<Gtk::StyleContext> WinContext =
 			make7window->get_style_context ();
 	WinContext->add_provider (CssProvider,
 			GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+	make7window->signal_delete_event (). connect
+			(sigc::mem_fun (*this, &Game::on_make7window_hide));
 	app->run (*make7window);
 }
 
-void
-Game::end_game ()
-{
-	Gtk::Label actual_score (current_score->get_label ());
-	box_score->pack_start (actual_score);
-	box_score->show ();
-	//  delete make7window;
-}
-
 void
 Game::import_every_widget ()
 {
 	Glib::RefPtr<Gtk::Builder> builder = Gtk::Builder::create_from_file
 			(UI_DIR "/basic.glade");
-
 	// Get every Make 7 windows
 	builder->get_widget ("make7window", make7window);
+	make7window->add_accel_group (Gtk::AccelGroup::create ());
 	builder->get_widget ("make7scores", make7scores);
-	builder->get_widget ("make7message", make7message);
 	builder->get_widget ("make7credits", make7credits);
 	builder->get_widget ("make7error_board", make7error_board);
+	builder->get_widget ("make7confirm", make7confirm);
+	builder->get_widget ("make7askname", make7askname);
+	builder->get_widget ("make7message", make7message);
+	// Get titlebar and menu actions
+	builder->get_widget ("headerbar", headerbar);
+	make7window->set_titlebar (*headerbar);
+	builder->get_widget ("newgame", newgame);
+	builder->get_widget ("scores", scores);
+	builder->get_widget ("credits", credits);
+	builder->get_widget ("quit", quit);
+	builder->get_widget ("appmenu", appmenu);
+	appmenu->set_accel_group (make7window->get_accel_group ());
 	// Get every interface buttons
 	builder->get_widget ("button_cancel", button_cancel);
 	builder->get_widget ("button_close_scores", button_close_scores);
-	builder->get_widget ("button_credits", button_credits);
 	builder->get_widget ("button_erase", button_erase);
 	builder->get_widget ("button_help", button_help);
-	builder->get_widget ("button_new", button_new);
 	builder->get_widget ("button_next", button_next);
-	builder->get_widget ("button_quit", button_quit);
-	builder->get_widget ("button_rotate", button_rotate);
-	builder->get_widget ("button_scores", button_scores);
-	// Get score label and box
+	builder->get_widget ("button_apply_save", button_save);
+	// Get score label, box and user entry
 	builder->get_widget ("current_score", current_score);
 	builder->get_widget ("box_score", box_score);
+	builder->get_widget ("user_entry", user_entry);
 	// Get every game buttons
 	// (board)
 	builder->get_widget ("nnw", nnw);
@@ -206,7 +224,7 @@ Game::import_every_widget ()
 	builder->get_widget ("mainE", mainE);
 	builder->get_widget ("mainSw", mainSw);
 	builder->get_widget ("mainSe", mainSe);
-	// For much more convenience, all these buttons are stocked in std::maps<int, std::string>
+	// For much more convenience, all these buttons are stocked in std::maps<int, Glib::ustring>
 	Board = { {13, nnw}, {14, nn}, {15, nne}, {22, nww},
 			{23, nw}, {24, ne}, {25, nee}, {31, ww},
 			{32, w}, {33, m}, {34, e}, {35, ee}, {41, sww},
@@ -220,7 +238,9 @@ Game::import_every_widget ()
 void
 Game::launch_game ()
 {
-	// Reset the score
+	// Get score list from file
+	get_scores ();
+	// Reset the current score
 	current_score->set_label ("0 pts");
 	// Reset the maximum of values proposed in selection area
 	max = 1;
@@ -238,6 +258,62 @@ Game::launch_game ()
  * /////////////////////////
  */
 
+void
+Game::big_badaboom (std::list<int> hexas)
+{
+	int nb;
+	for (int hexa : hexas)
+	{
+		for (int key : SelectionAreaKeys)
+		{
+			nb = get_neighbour (key, hexa);
+			if (nb != -42 && Board[nb]->get_label () != "")
+			{
+				Board[nb]->set_label ("");
+				update_hexa_color (nb);
+			}
+		}
+	}
+}
+
+void
+Game::check_end ()
+{
+	std::map<int, Glib::ustring> tmpBoard = get_board_snapshot ();
+	int nFull = 0, nEmpty = 0;
+	for (auto const& hexa : tmpBoard)
+	{
+		if (hexa.second == "")
+			nEmpty++;
+		else
+			nFull++;
+	}
+	if (nEmpty == 19)
+	{
+		make7message->set_message ("Congratulation, you win !");
+		if (make7message->run ())
+		{
+			make7message->hide ();
+			write_scores ();
+			/* TODO
+			 * Not a new game, but a new board !!!
+			 */
+			launch_game ();
+		}
+	}
+	if (nFull == 19)
+	{
+		make7message->set_message ("You lose, no more place available !\nTry again !");
+		make7message->show ();
+		if (make7message->run ())
+		{
+			make7message->hide ();
+			write_scores ();
+			launch_game ();
+		}
+	}
+}
+
 void
 Game::display_error (int i)
 {
@@ -257,35 +333,14 @@ Game::display_error (int i)
 }
 
 void
-Game::define_hexa (int ref, std::string valref)
+Game::define_hexa (int ref, Glib::ustring valref)
 {
 	// Update the label
 	Board[ref]->set_label (valref);
 	update_hexa_color (ref);
 	// This functions calls every half-second define_hexa(), until it returns false
-	sigc::slot<bool> my_slot = sigc::bind (sigc::mem_fun (*this, &Game::triggers), ref);
-	Glib::signal_timeout ().connect (my_slot, 500);
-}
-
-bool
-Game::triggers (int ref)
-{
-	std::list<int> matchingNbs;
-	matchingNbs = {ref};
-	scan_neighbours (ref, matchingNbs);
-	// In case there are at least two matching neighbors
-	if (matchingNbs.size () > 2)
-	{
-		// Merge them
-		merge_hexas (ref, matchingNbs);
-		// and update the score
-		nMatch = matchingNbs.size () * 10;
-		refresh_score ();
-		// Then tell to define_hexas() that it is not finished !
-		return true;
-	}
-	// Else stop here
-	return false;
+	Glib::signal_timeout ().connect
+			(sigc::bind (sigc::mem_fun (*this, &Game::triggers), ref), 500);
 }
 
 void
@@ -303,25 +358,36 @@ Game::erase_hexa (int ref)
 		}
 	}
 	button_erase->set_active (false);
+	// At this point, the game could be finished.
+	check_end ();
 	return;
+}
 
+std::map<int, Glib::ustring>
+Game::get_board_snapshot ()
+{
+	std::map<int, Glib::ustring> map;
+	for (int i : BoardKeys)
+		map[i] = Board[i]->get_label ();
+	return map;
 }
 
 void
 Game::game_button_selected (int ref)
 {
 	// Backup the board and the selection area
-	get_snapshot ();
+	BoardSnapshotMap = get_board_snapshot ();
+	store_oldvalhexas ();
+	button_cancel->set_sensitive(true);
+
 	/* Now the following actions can be triggered : */
 	// Are we erasing this hexa ?
 	if (button_erase->get_active ())
 		erase_hexa (ref);
-	// Are we trying to rotate the main and second hexas ?
-	else if (ref == 0)
-		on_rotate_hexas_activate ();
 	// Are we defining a new hexa(s) ?
 	else if (Board[ref]->get_label () == "")
 	{
+		bool there_is_a_second_hexa_to_define = false;
 		int nb = -42;
 		if (pos2 != -42)
 		{
@@ -338,11 +404,13 @@ Game::game_button_selected (int ref)
 			}
 			else
 				// If there is a second hexa, and it doesn't override an existing value,
-				// neither out of the board, then put its value on the board
-				define_hexa (nb, get_second_hexa ());
+				// neither is out of the board, then put its value on the board
+				there_is_a_second_hexa_to_define = true;
 		}
 		// Put the value of the main hexa on the board it it doesn't override an existing value
 		define_hexa (ref, get_main_hexa ());
+		if (there_is_a_second_hexa_to_define)
+			define_hexa (nb, get_second_hexa ());
 		// Then it starts a new turn
 		get_random_hexas ();
 		refresh_selection_area ();
@@ -351,12 +419,55 @@ Game::game_button_selected (int ref)
 		display_error (1);
 }
 
+Glib::ustring
+Game::get_config_file ()
+{
+	Glib::ustring configdir = Glib::get_user_config_dir () + "/make7libre";
+	Glib::ustring filepath = configdir + "/history";
+	if (file_test (filepath, Glib::FILE_TEST_IS_REGULAR))
+		return filepath;
+	else
+	{
+		// Create directory
+		mkdir (configdir.c_str (), 0755);
+		Glib::KeyFile *new_config_file = new Glib::KeyFile ();
+		// Get current time
+		Glib::TimeVal *cur_time = new Glib::TimeVal;
+		cur_time->assign_current_time ();
+		Glib::ustring top_comment = " This file was firstly created by Make7Libre, the "
+				+ cur_time->as_iso8601 ();
+		// Fill and create the file
+		new_config_file->set_comment (top_comment);
+		new_config_file->save_to_file (filepath);
+		return filepath;
+	}
+}
+
+
+bool
+Game::get_confirmation ()
+{
+	if (make7confirm->run () == -8)
+	{
+		make7confirm->hide ();
+		if (std::stoi (current_score->get_label ()) != 0)
+			write_scores ();
+		return true;
+	}
+	// else
+	make7confirm->hide ();
+	return false;
+}
+
 Glib::ustring
 Game::get_main_hexa ()
 {
 	return mainM->get_label ();
 }
 
+/** Get the hexa around the given one (ref)
+ *
+ */
 int
 Game::get_neighbour (int rel, int ref)
 {
@@ -406,6 +517,36 @@ Game::get_random_hexas ()
 	}
 }
 
+void
+Game::get_scores ()
+{
+	Glib::ustring config_file = get_config_file ();
+	Glib::KeyFile *saved_scores = new Glib::KeyFile ();
+	saved_scores->load_from_file (config_file);
+	// Clear box_score
+	std::vector<Gtk::Widget*> old_score_vect = box_score->get_children();
+	for (Gtk::Widget* old_score : old_score_vect)
+	{
+		box_score->remove (*old_score);
+	}
+	if (saved_scores->has_group ("Scores"))
+	{
+		Glib::ArrayHandle<Glib::ustring> names =  saved_scores->get_keys ("Scores");
+		for (Glib::ustring user : names)
+		{
+			std::list<int> user_scores = saved_scores->get_integer_list ("Scores", user);
+			for (int u_score : user_scores)
+			{
+				Gtk::Label *user_score_label = new Gtk::Label ();
+				Glib::ustring line = user + "\t: " + std::to_string (u_score);
+				user_score_label->set_text (line);
+				box_score->pack_start (*user_score_label);
+			}
+		}
+		box_score->show_all ();
+	}
+}
+
 Glib::ustring
 Game::get_second_hexa ()
 {
@@ -414,18 +555,6 @@ Game::get_second_hexa ()
 	return "nosecondhexa";
 }
 
-void
-Game::get_snapshot ()
-{
-	for (int i : BoardKeys)
-		BoardSnapshotMap[i] = Board[i]->get_label ();
-	oldValHexa1 = get_main_hexa ();
-	if (get_second_hexa () != "")
-		oldValHexa2 = get_second_hexa ();
-	else
-		oldValHexa2 = "";
-}
-
 void
 Game::merge_hexas (int newHexa, std::list<int> oldHexas)
 {
@@ -446,8 +575,7 @@ Game::merge_hexas (int newHexa, std::list<int> oldHexas)
 			max = val;
 		if (val == 8)
 		{
-			// No more hexas, 100 pts bonus
-			Board[newHexa]->set_label ("");
+			big_badaboom (oldHexas);
 			nMatch = 100;
 			refresh_score ();
 		}
@@ -476,13 +604,16 @@ Game::on_close_scores_activate ()
 void
 Game::on_display_credits_activate ()
 {
-	make7credits->show ();
+	if (make7credits->run () == -4)
+		make7credits->hide ();
 }
 
 void
 Game::on_display_help_activate ()
 {
-	make7message->show ();
+	// TODO
+	// Display help
+	system ("yelp");
 }
 
 void
@@ -492,15 +623,26 @@ Game::on_display_scores_activate ()
 }
 
 void
-Game::on_erase_hexa_activate ()
+Game::on_entry_editing_done ()
 {
+	std::cout << "Event enter !!!" << std::endl;
+	button_save->clicked ();
+}
+
+bool
+Game::on_make7window_hide (_GdkEventAny* event)
+{
+	if (get_confirmation ())
+		return false;
+	else
+		return true;
 }
 
 void
 Game::on_new_game_activate ()
 {
-	end_game ();
-	launch_game ();
+	if (get_confirmation ())
+		launch_game ();
 }
 
 void
@@ -517,29 +659,7 @@ Game::on_next_hexa_activate ()
 void
 Game::on_quit_game_activate ()
 {
-	end_game ();
-	if (make7window)
-		make7window->hide ();
-}
-
-void
-Game::on_rotate_hexas_activate ()
-{
-	int actualPos2 = get_pos2 ();
-	if (actualPos2 == -10)
-		set_pos2 (-9);
-	if (actualPos2 == -9)
-		set_pos2 (1);
-	if (actualPos2 == 1)
-		set_pos2 (10);
-	if (actualPos2 == 10)
-		set_pos2 (9);
-	if (actualPos2 == 9)
-		set_pos2 (-1);
-	if (actualPos2 == -1)
-		set_pos2 (-10);
-	reset_selection_area ();
-	refresh_selection_area ();
+	make7window->close ();
 }
 
 int
@@ -547,7 +667,7 @@ Game::refresh_score ()
 {
 	int Iscore = std::stoi (current_score->get_label ());
 	Iscore += nMatch;
-	std::string Sscore = std::to_string (Iscore) + " pts";
+	Glib::ustring Sscore = std::to_string (Iscore) + " pts";
 	if (Iscore >= 0)
 		current_score->set_label (Sscore);
 	else
@@ -600,12 +720,57 @@ Game::reset_snapshot ()
 	}
 	set_pos2 (9);
 	valHexa1 = std::stoi (oldValHexa1);
-	if (oldValHexa2 != "")
+	if (oldValHexa2 != "nosecondhexa")
 		valHexa2 = std::stoi (oldValHexa2);
 	else
-		valHexa2 = -42;
+		pos2 = -42;
 	reset_selection_area ();
 	refresh_selection_area ();
+	button_cancel->set_sensitive(false);
+}
+
+void
+Game::rotate_hexas_left ()
+{
+	int actualPos2 = get_pos2 ();
+	if (actualPos2 == -10)
+		set_pos2 (-9);
+	if (actualPos2 == -9)
+		set_pos2 (1);
+	if (actualPos2 == 1)
+		set_pos2 (10);
+	if (actualPos2 == 10)
+		set_pos2 (9);
+	if (actualPos2 == 9)
+		set_pos2 (-1);
+	if (actualPos2 == -1)
+		set_pos2 (-10);
+	reset_selection_area ();
+	refresh_selection_area ();
+}
+
+bool
+Game::rotate_hexas_right (GdkEventButton* event)
+{
+	int actualPos2 = get_pos2 ();
+	if (event->button == 3)
+	{
+		if (actualPos2 == -10)
+			set_pos2 (-1);
+		if (actualPos2 == -9)
+			set_pos2 (-10);
+		if (actualPos2 == 1)
+			set_pos2 (-9);
+		if (actualPos2 == 10)
+			set_pos2 (1);
+		if (actualPos2 == 9)
+			set_pos2 (10);
+		if (actualPos2 == -1)
+			set_pos2 (9);
+	}
+	reset_selection_area ();
+	refresh_selection_area ();
+	return true;
 }
 
 bool
@@ -641,7 +806,7 @@ Game::scan_neighbours (int ref, std::list<int> &oldRefs)
 }
 
 void
-Game::set_main_hexa (std::string Snum)
+Game::set_main_hexa (Glib::ustring Snum)
 {
 	mainM->set_label (Snum);
 	Glib::PropertyProxy<Gtk::ReliefStyle> prop =
@@ -658,7 +823,7 @@ Game::set_pos2 (int givenPos2)
 }
 
 void
-Game::set_second_hexa (std::string Snum)
+Game::set_second_hexa (Glib::ustring Snum)
 {
 	if (pos2 != -42)
 	{
@@ -671,6 +836,39 @@ Game::set_second_hexa (std::string Snum)
 	}
 }
 
+void
+Game::store_oldvalhexas ()
+{
+	oldValHexa1 = get_main_hexa ();
+	if (get_second_hexa () != "")
+		oldValHexa2 = get_second_hexa ();
+	else
+		oldValHexa2 = "";
+}
+
+bool
+Game::triggers (int ref)
+{
+	std::list<int> matchingNbs;
+	matchingNbs = {ref};
+	scan_neighbours (ref, matchingNbs);
+	// In case there are at least two matching neighbors
+	if (matchingNbs.size () > 2)
+	{
+		// Merge them
+		merge_hexas (ref, matchingNbs);
+		// and update the score
+		nMatch = matchingNbs.size () * 10;
+		refresh_score ();
+		// Then tell to define_hexas() that it is not finished !
+		return true;
+	}
+	// At this point, the game can be finished.
+	check_end ();
+	// Stop
+	return false;
+}
+
 void
 Game::update_hexa_color (int hexa)
 {
@@ -702,3 +900,33 @@ Game::update_hexa_color (int hexa)
 	else
 		HexaContext->add_class ("nocolor");
 }
+
+void
+Game::write_scores ()
+{
+	// Get config file
+	Glib::ustring config_file = get_config_file ();
+	Glib::KeyFile *saved_scores;
+	saved_scores = new Glib::KeyFile ();
+	saved_scores->load_from_file (config_file);
+	// If the user wants to save his score
+	if (make7askname->run () == 10)
+	{
+		// Get his name
+		Glib::ustring username = user_entry->get_text();
+		// Get his old score (eventually)
+		std::list<int> Lscore;
+		if (saved_scores->has_group("Scores"))
+		{
+			if (saved_scores->has_key("Scores", username))
+				Lscore = saved_scores->get_integer_list ("Scores", username);
+		}
+		// Add current score
+		Lscore.push_back (std::stoi (current_score->get_label ()));
+		saved_scores->set_integer_list ("Scores", username, Lscore);
+		// Save it
+		saved_scores->save_to_file (config_file);
+		make7scores->show ();
+	}
+	make7askname->hide ();
+}
