@@ -38,14 +38,12 @@ main (int argc, char** argv)
   Game* game = new Game ();
   /* Seeding the random */
   srand (time (NULL));
-  /* Importation */
+  /* Preparing GUI and starting the game */
   game->import_every_widget ();
-  /* Connexion */
   game->connect_every_button ();
-  /* First game */
   game->launch_game ();
   game->display (app);
-  game->end_game ();
+  // End
   return 0;
 }
 
